@@ -4,17 +4,17 @@ from testcontainers_on_whales import Container
 
 
 class NginxContainer(Container):
-    NGINX_PORT = 80
+    NGINX_PORT = 8080
 
     def __init__(
         self,
-        image: str = "docker.io/library/nginx:alpine",
+        image: str = "docker.io/nginxinc/nginx-unprivileged:alpine",
     ) -> None:
         super().__init__(image=image)
 
     def get_connection_url(self) -> str:
-        ip = self.get_host_ip()
-        port = self.get_exposed_port(self.NGINX_PORT)
+        ip = self.get_container_ip()
+        port = self.get_container_port(self.NGINX_PORT)
         return f"http://{ip}:{port}"
 
     def readiness_probe(self) -> bool:
